@@ -1,6 +1,6 @@
 #! /bin/bash
 
-# $Id: build.sh,v 1.13 2004/04/30 12:51:31 jt Exp $
+# $Id: build.sh,v 1.14 2004/08/19 11:35:05 jt Exp $
 
 # parse arguments
 version=$1
@@ -38,9 +38,6 @@ find $InstallPrefix -name '*.exe' -o -name '*.dll' | xargs chmod u+w
 # strip executables
 find $InstallPrefix -name '*.exe' -o -name '*.dll' | xargs strip 
 
-# create man cat dirs
-mkdir $ManDir/cat1
-
 # copy README file
 mkdir -p $CygDocDir
 cp $PatchDir/README $CygDocDir/$pkg-$version.README
